@@ -26,6 +26,7 @@ class Config:
         self.backfill: bool = bool(model_settings["backfill"])
         self.dependencies: List = model_settings.get("dependencies", [])
         self.air_infrastructure: bool = bool(config.get("airInfra"))
+        self.load_balancer: bool = bool(config.get("loadBalancer"))
         self.secret_names: List[str] = model_settings.get("secrets")
         self.fields: Union[Fields, None] = Fields(config.get("fields", {})) if config.get("fields") else None
         self.visualization: Union[Visualization, None] = (
@@ -53,6 +54,8 @@ class Config:
             convert.update({"dependencies": self.dependencies})
         if self.air_infrastructure:
             convert.update({"airInfra": self.air_infrastructure})
+        if self.load_balancer:
+            convert.update({"load_balancer": self.load_balancer})
         if self.fields:
             convert.update({"fields": self.fields.to_dict()})
         if self.visualization:
